@@ -42,5 +42,16 @@ int extract_icons(FILE *in, const char *inname, bool listmode, ExtractNameGen ou
 
 /* create.c */
 typedef FILE *(*CreateNameGen)(char **outname);
-bool create_icon(size_t filec, char **filev, size_t raw_filec, char** raw_filev, CreateNameGen outfile_gen, bool icon_mode, int32_t hotspot_x, int32_t hotspot_y, int32_t alpha_threshold, int32_t bit_count);
+typedef struct InputFile_s {
+    char *name;
+    bool is_raw;
+    int32_t bit_count;
+    int32_t hotspot_x;
+    int32_t hotspot_y;
+} InputFile;
+typedef struct InputFiles_s {
+    size_t count;
+    InputFile *files;
+} InputFiles;
+bool create_icon(InputFiles *files, CreateNameGen outfile_gen, bool icon_mode, int32_t alpha_threshold);
 #endif
